==> dde-session-shell_5.5.66.orig.tar.xz: dde-session-shell-5.5.66/translations/dde-session-shell_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>ID de cara</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificación fallida, queda %n oportunidad</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verificación fallida, sólo queda una oportunidad</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifique su ID de cara</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>ID de cara bloqueado, utilice la contraseña por favor</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique su huella dactilar</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificación fallida, quedan %n oportunidades</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La verificación falló, solo queda un intento</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Huella dactilar bloqueada, use la contraseña por favor</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>ID de Iris</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificación fallida, queda %n oportunidad</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verificación fallida, sólo queda una oportunidad</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifique su ID de Iris</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>ID de Iris bloqueado, utilice la contraseña por favor</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificación fallida, queda %n oportunidad</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La verificación falló, solo queda un intento</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contraseña Incorrecta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Por favor, inténtelo de nuevo 1 minuto más tarde</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Por favor, inténtelo de nuevo %n minutos más tarde</numerusform><numerusform>Por favor, inténtelo de nuevo %n minutos más tarde</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Restablecer contraseña</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>¿Ha olvidado su contraseña?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Vuelve a intentarlo después de 1 minuto.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Por favor, inténtelo de nuevo %n minutos más tarde</numerusform><numerusform>Por favor, inténtelo de nuevo %n minutos más tarde</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reestablecer contraseña</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>¿Ha olvidado su contraseña?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificación fallida, queda %n oportunidad</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La verificación falló, solo queda un intento</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN Incorrecto</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Se requiere UKey</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Introduzca su PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Por favor, inténtelo de nuevo %n minuto(s) más tarde</numerusform><numerusform>Por favor, inténtelo de nuevo %n minuto(s) más tarde</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Por favor, inténtelo de nuevo 1 minuto más tarde</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Por favor, inténtelo de nuevo %n minutos más tarde</numerusform><numerusform>Por favor, inténtelo de nuevo %n minutos más tarde</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Cuenta</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Su contraseña expirará en %n día, por favor, cámbiela a tiempo</numerusform><numerusform>Su contraseña expirará en %n días, por favor, cámbiela a tiempo</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>La contraseña ha caducado, por favor, cámbiela</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Cuenta errónea</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contraseña Incorrecta</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Bloquear pantalla</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>No se ha podido bloquear la pantalla</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Tiempo de verificación de huella dactilar agotado, escriba su contraseña</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>La comprobación dactilar falló</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Hay usuarios conectados y sus datos se perderán al apagar, ¿está seguro de que desea apagar?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Hay usuarios conectados y sus datos se perderán al reiniciar, ¿está seguro de que desea reiniciar?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Ha habilitado el nivel alto de seguridad del sistema, por lo que no puede cambiar al modo Wayland, desactive el nivel alto de seguridad en el Centro de seguridad e intente nuevamente.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Cerrar sesión</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Cambiar usuario</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Cambiar sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Iniciar el monitor del sistema</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Los programas están evitando que el equipo se apague, y forzar el apagado podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para cerrar el programa, haga clic en Cancelar y luego cierre.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Los programas están evitando que el equipo se reinicie, y forzar el reinicio podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Los programas están evitando que el equipo se suspenda, y forzar la suspensión podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Los programas están evitando que el equipo se hiberne, y forzar la hibernación podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Los programas están evitando que el equipo cierre sesión, y forzar el cerrado podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Cerrar sesión</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>¿Seguro que desea apagar?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>¿Seguro que desea reiniciar?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>¿Seguro que desea cerrar sesión?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Desactivar</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.81.orig.tar.xz: dde-session-shell-5.5.81/translations/dde-session-shell_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>ID de cara</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verificación fallida, sólo queda una oportunidad</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifique su ID de cara</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>ID de cara bloqueado, utilice la contraseña por favor</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>¡Dispositivo no disponible!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique su huella dactilar</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificación fallida, quedan %n oportunidades</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La verificación falló, solo queda un intento</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Huella dactilar bloqueada, use la contraseña por favor</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>ID de Iris</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verificación fallida, sólo queda una oportunidad</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifique su ID de Iris</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>ID de Iris bloqueado, utilice la contraseña por favor</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificación fallida, queda %n oportunidad</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La verificación falló, solo queda un intento</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contraseña Incorrecta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Por favor, inténtelo de nuevo 1 minuto más tarde</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Restablecer contraseña</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>¿Ha olvidado su contraseña?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Vuelve a intentarlo después de 1 minuto.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Por favor, inténtelo de nuevo %n minutos más tarde</numerusform><numerusform>Por favor, inténtelo de nuevo %n minutos más tarde</numerusform><numerusform>Por favor, inténtelo de nuevo %n minutos más tarde</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reestablecer contraseña</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>¿Ha olvidado su contraseña?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificación exitosa</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificación fallida, queda %n oportunidad</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform><numerusform>Verificación fallida, quedan %n oportunidades</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La verificación falló, solo queda un intento</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN Incorrecto</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Se requiere UKey</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Introduzca su PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Por favor, inténtelo de nuevo %n minuto(s) más tarde</numerusform><numerusform>Por favor, inténtelo de nuevo %n minuto(s) más tarde</numerusform><numerusform>Por favor, inténtelo de nuevo %n minuto(s) más tarde</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Por favor, inténtelo de nuevo 1 minuto más tarde</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Cuenta</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>La contraseña ha caducado, por favor, cámbiela</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Cuenta errónea</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contraseña Incorrecta</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Bloquear pantalla</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>No se ha podido bloquear la pantalla</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Tiempo de verificación de huella dactilar agotado, escriba su contraseña</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>La comprobación dactilar falló</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Hay usuarios conectados y sus datos se perderán al apagar, ¿está seguro de que desea apagar?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Hay usuarios conectados y sus datos se perderán al reiniciar, ¿está seguro de que desea reiniciar?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Ha habilitado el nivel alto de seguridad del sistema, por lo que no puede cambiar al modo Wayland, desactive el nivel alto de seguridad en el Centro de seguridad e intente nuevamente.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Cerrar sesión</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Cambiar usuario</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Cambiar sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Iniciar el monitor del sistema</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Los programas están evitando que el equipo se apague, y forzar el apagado podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para cerrar el programa, haga clic en Cancelar y luego cierre.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Los programas están evitando que el equipo se reinicie, y forzar el reinicio podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Los programas están evitando que el equipo se suspenda, y forzar la suspensión podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Los programas están evitando que el equipo se hiberne, y forzar la hibernación podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Los programas están evitando que el equipo cierre sesión, y forzar el cerrado podría causar pérdida de datos.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Cerrar sesión</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>¿Seguro que desea apagar?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>¿Seguro que desea reiniciar?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>¿Seguro que desea cerrar sesión?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Desactivar</translation>
    </message>
</context>
</TS>
